import ctypes, sys

def win_symlink(source, link_name):
  import os
  import ctypes
  source = os.path.abspath(source)
  link_name = os.path.abspath(link_name)
  csl = ctypes.windll.kernel32.CreateSymbolicLinkW
  csl.argtypes = (ctypes.c_wchar_p, ctypes.c_wchar_p, ctypes.c_uint32)
  csl.restype = ctypes.c_ubyte
  flags = 1 if os.path.isdir(source) else 0
  if csl(link_name, source, flags) == 0:
    raise ctypes.WinError()

    
def is_admin():
    try:
        return ctypes.windll.shell32.IsUserAnAdmin()
    except:
        return False

if sys.platform.startswith("linux") or sys.platform.startswith("darwin") or is_admin():

  import os, glob, site
  from distutils.core import setup

  setup(
      name = "terralib",
      version = "5.3.2",
      author = "TerraLib Team",
      author_email = "terralib-team@terralib.org",
      description = ("A python binding for the TerraLib C++ Library"),
      license = "LGPL",
      keywords = "terralib geo",
      url = "http://dpi.inpe.br/terralib5",
      packages=["terralib"],
      package_data={"terralib":["*.so", "*.dll", "*.dylib", "*.pyd"]}
  )

  if sys.platform.startswith("win32"):
    dlls = glob.glob("..\\..\\bin\\*.dll")
    dest_dir = ""
    if "--user" in sys.argv:
      dest_dir  = site.getusersitepackages() + "\\terralib"
    else: 
      dest_dir = site.getsitepackages()[1] + "\\terralib"
    
    for dll in dlls:
      win_symlink(dll, dest_dir + "\\" + os.path.basename(dll))

else:
  if(sys.platform.startswith("win32")):
    print("Cannot create symlink for library dependencies.\nPlease re-run setup.py as administrator!")
  else:
    print("Unsupported platform")

