BEGIN;

create schema terraamazon;

create table terraamazon.ta_catalog
(
  id           serial not null primary key,
  name         character varying (255),
  uri          character varying (255),
  source_type  character varying (255),
  permission   integer,
  last_edition timestamp without time zone,
  author       character varying (255),
  source       character varying (255),
  description  character varying (255),
  scale_min    double precision,
  scale_max    double precision,
  style        text,
  cell_column  character varying (255),
  locked       boolean
);

create table terraamazon.ta_cell_layer
(
  catalog_id integer REFERENCES terraamazon.ta_catalog(id) not null primary key,
  resolution double precision,
  active     boolean,
  CONSTRAINT ta_cell_layer_catalog_id_uq UNIQUE (catalog_id)
);

create table terraamazon.ta_project
(
  id           serial not null primary key,
  name         character varying (255),
  active       boolean,
  min_scale    double precision,
  max_scale    double precision,
  created_on   date,
  updated_on   date,
  maxcells     integer default 6
);

create table terraamazon.ta_area_calculation
(
  project_id       integer REFERENCES terraamazon.ta_project(id),
  min_area         double precision,
  unit_measurement character varying (255),
  srs_proj4        character varying (255),
  CONSTRAINT ta_area_calculation_pkey PRIMARY KEY (project_id)
);

create table terraamazon.ta_class
(
  id          	serial not null primary key,
  name        	character varying (255),
  description 	character varying (255),
  lccs_name 	character varying (255),
  lccs_mapcode 	character varying (255),
  style      	character varying (255)
);

create table terraamazon.ta_ruleset
(
  id         serial not null primary key,
  catalog_id integer REFERENCES terraamazon.ta_catalog(id),
  name       character varying (255),
  CONSTRAINT ta_ruleset_catalog_id_uq UNIQUE (catalog_id)
);

create table terraamazon.ta_rule
(
  id                   serial not null primary key,
  name                 character varying (255),
  catalog_id           integer REFERENCES terraamazon.ta_catalog(id),
  operation_id         integer
);

create table terraamazon.ta_aoi_layer
(
  catalog_id     integer REFERENCES terraamazon.ta_catalog(id) not null primary key,
  aoi_id_column  character varying (255)
);

create table terraamazon.ta_scene
(
  id             serial not null primary key,
  view_date      date,
  julday         integer,
  inclusion      timestamp without time zone,
  ai_object_id   character varying (255),
  aoi_layer_id    integer REFERENCES terraamazon.ta_aoi_layer(catalog_id)
);

create table terraamazon.ta_phase
(
  id          serial not null primary key,
  description character varying (255)
);

create table terraamazon.ta_group
(
  id          serial not null primary key,
  name        character varying (255),
  privileges  integer
);

create table terraamazon.ta_user
(
  id           serial not null primary key,
  project_id   integer REFERENCES terraamazon.ta_project(id),
  name         character varying (255),
  password     character varying (255),
  email        character varying (255),
  active       boolean,
  date_i       date,
  date_f       date
);

create table terraamazon.ta_revision
(
  id             serial not null primary key,
  slave_user_id  integer REFERENCES terraamazon.ta_user(id),
  master_user_id integer REFERENCES terraamazon.ta_user(id),
  project_id     integer REFERENCES terraamazon.ta_project(id),
  obs            character varying (255),
  status         character varying (255)
);

create table terraamazon.ta_task
(
  id         serial not null primary key,
  scene_id   integer REFERENCES terraamazon.ta_scene(id),
  project_id integer REFERENCES terraamazon.ta_project(id),
  phase_id    integer REFERENCES terraamazon.ta_phase(id),
  user_id    integer REFERENCES terraamazon.ta_user(id)
);

create table terraamazon.ta_tagtask
(
  id           serial not null primary key,
  task_id      integer REFERENCES terraamazon.ta_task(id),
  project_id   integer REFERENCES terraamazon.ta_project(id),
  label        character varying (255),
  initial_date date,
  final_date   date
);

create table terraamazon.ta_tasklog
(
  id           serial not null primary key,
  task_id      integer REFERENCES terraamazon.ta_task(id),
  status       character varying (255),
  initial_time timestamp without time zone,
  final_time   timestamp without time zone,
  timer        integer,
  obs          character varying (255)
);

create table terraamazon.ta_process
(
  id         serial not null primary key,
  tasklog_id integer REFERENCES terraamazon.ta_tasklog(id),
  task_id    integer REFERENCES terraamazon.ta_task(id)
);

create table terraamazon.ta_ruleset_project
(
  ruleset_id integer REFERENCES terraamazon.ta_ruleset(id),
  project_id integer REFERENCES terraamazon.ta_project(id),
  CONSTRAINT ta_ruleset_project_pkey PRIMARY KEY (ruleset_id, project_id)
);

create table terraamazon.ta_ruleset_class
(
  ruleset_id integer REFERENCES terraamazon.ta_ruleset(id),
  class_id   integer REFERENCES terraamazon.ta_class(id),
  CONSTRAINT ta_ruleset_class_pkey PRIMARY KEY (ruleset_id, class_id)
);

create table terraamazon.ta_rule_ruleset
(
  ruleset_id integer REFERENCES terraamazon.ta_ruleset(id),
  rule_id    integer REFERENCES terraamazon.ta_rule(id),
  priority   integer,
  CONSTRAINT ta_rule_ruleset_pkey PRIMARY KEY (ruleset_id, rule_id)
);

create table terraamazon.ta_project_scene
(
  project_id integer REFERENCES terraamazon.ta_project(id),
  scene_id   integer REFERENCES terraamazon.ta_scene(id),
  locked     boolean,
  CONSTRAINT ta_project_scene_pkey PRIMARY KEY (project_id, scene_id)
);

create table terraamazon.ta_group_phase
(
  group_id integer REFERENCES terraamazon.ta_group(id),
  phase_id  integer REFERENCES terraamazon.ta_phase(id),
  CONSTRAINT ta_group_phase_pkey PRIMARY KEY (group_id, phase_id)
);

create table terraamazon.ta_group_user
(
  group_id integer REFERENCES terraamazon.ta_group(id),
  user_id  integer REFERENCES terraamazon.ta_user(id),  
  CONSTRAINT ta_group_user_pkey PRIMARY KEY (user_id, group_id)
);

create table terraamazon.ta_preferences
(
  user_id   integer REFERENCES terraamazon.ta_user(id),
  key       character varying (255),
  value     character varying (255),
  all_users boolean,
  CONSTRAINT ta_preferences_pkey PRIMARY KEY (user_id, key)
);

create table terraamazon.ta_version
(
  version character varying (255) not null primary key,
  caption character varying (255)
);

create table terraamazon.ta_rules_layer_params
(
  catalog_id   integer REFERENCES terraamazon.ta_catalog(id),
  class_column character varying (255),
  CONSTRAINT   ta_rules_layer_params_pkey PRIMARY KEY (catalog_id, class_column)
);

create table terraamazon.ta_rules_layer_column
(
  id         serial not null primary key,
  rule_id    integer REFERENCES terraamazon.ta_rule(id),
  ruleset_id integer REFERENCES terraamazon.ta_ruleset(id),
  column_in  character varying (255),
  column_out character varying (255),
  CONSTRAINT ta_rules_layer_column_ruleset_id_column_out_uq UNIQUE (ruleset_id, column_out)
);

create table terraamazon.ta_connected_users
(
  connection_id integer NOT NULL primary key,
  process_id integer REFERENCES terraamazon.ta_process(id),
  user_id integer REFERENCES terraamazon.ta_user(id)
);

create table terraamazon.ta_notification
(
  id serial    not null primary key,
  to_user_id   integer REFERENCES terraamazon.ta_user(id),
  from_user_id integer REFERENCES terraamazon.ta_user(id),
  message      character varying,
  datetime     date,
  type         integer
);

create table terraamazon.ta_notification_unread
(
  to_user_id      integer REFERENCES terraamazon.ta_user(id),
  notification_id integer REFERENCES terraamazon.ta_notification(id),
  CONSTRAINT      ta_notification_unread_pkey PRIMARY KEY (to_user_id, notification_id)
);

create table terraamazon.ta_grp4class
(
  id          serial not null primary key,
  name        character varying,
  description character varying
);

create table terraamazon.ta_class_grp4class
(
  class_id     integer REFERENCES terraamazon.ta_class(id),
  grp4class_id integer REFERENCES terraamazon.ta_grp4class(id),
  CONSTRAINT   ta_class_grp4class_pkey PRIMARY KEY (class_id, grp4class_id)
);

create table terraamazon.ta_image_server
(
  id          serial not null primary key,
  alias       character varying (255),
  url         character varying (255),
  description character varying (255)
);

create table terraamazon.ta_project_image_server
(
  id          serial not null primary key,
  proj_id     integer REFERENCES terraamazon.ta_project(id),
  server_id   integer REFERENCES terraamazon.ta_image_server(id),
  CONSTRAINT  ta_project_image_server_proj_id_server_id_uq UNIQUE (proj_id, server_id)
);

create table terraamazon.ta_project_image_server_layers
(
  id              serial not null primary key,
  proj_server_id  integer REFERENCES terraamazon.ta_project_image_server(id),
  layer_name      character varying (255),
  type            integer
);

 create table terraamazon.ta_celllog
(
  id            serial not null primary key,
  project_id    integer REFERENCES terraamazon.ta_project(id),
  task_id       integer REFERENCES terraamazon.ta_task(id),
  catalog_id    integer REFERENCES terraamazon.ta_catalog(id),
  user_id       integer REFERENCES terraamazon.ta_user(id),
  cell_id       character varying (255),
  status        character varying (255),
  time          timestamp without time zone,
  finalized     boolean,
  area          double precision
);

CREATE UNIQUE INDEX ta_user_unique_name ON terraamazon.ta_user (name);

INSERT INTO terraamazon.ta_group (name, privileges) VALUES ('Administrator', 7);
INSERT INTO terraamazon.ta_group (name, privileges) VALUES ('Project Manager', 3);
INSERT INTO terraamazon.ta_group (name, privileges) VALUES ('Operator', 1);

INSERT INTO terraamazon.ta_phase (description) VALUES ('Interpretation');

INSERT INTO terraamazon.ta_group_phase (group_id, phase_id) VALUES (3, 1);

INSERT INTO terraamazon.ta_version (version) values ('1.3');

COMMIT;